package com.solution.system.service;

import java.util.List;
import com.solution.system.domain.Templateparameterdef;

/**
 * 模板参数定义Service接口
 * 
 * @author ruoyi
 * @date 2026-02-05
 */
public interface ITemplateparameterdefService 
{
    /**
     * 查询模板参数定义
     * 
     * @param id 模板参数定义主键
     * @return 模板参数定义
     */
    public Templateparameterdef selectTemplateparameterdefById(Long id);

    /**
     * 查询模板参数定义列表
     * 
     * @param templateparameterdef 模板参数定义
     * @return 模板参数定义集合
     */
    public List<Templateparameterdef> selectTemplateparameterdefList(Templateparameterdef templateparameterdef);

    /**
     * 新增模板参数定义
     * 
     * @param templateparameterdef 模板参数定义
     * @return 结果
     */
    public int insertTemplateparameterdef(Templateparameterdef templateparameterdef);

    /**
     * 修改模板参数定义
     * 
     * @param templateparameterdef 模板参数定义
     * @return 结果
     */
    public int updateTemplateparameterdef(Templateparameterdef templateparameterdef);

    /**
     * 批量删除模板参数定义
     * 
     * @param ids 需要删除的模板参数定义主键集合
     * @return 结果
     */
    public int deleteTemplateparameterdefByIds(Long[] ids);

    /**
     * 删除模板参数定义信息
     * 
     * @param id 模板参数定义主键
     * @return 结果
     */
    public int deleteTemplateparameterdefById(Long id);
}
